AnsiColor enum
this class abstracts how ansi colors are defined
if you want to know more about ansi colors: https://en.wikipedia.org/wiki/ANSI_escape_code#Colors
- Inheritance
- Implemented types
- Available extensions
Values
- black → const AnsiColor
-
this class abstracts how ansi colors are defined
if you want to know more about ansi colors: https://en.wikipedia.org/wiki/ANSI_escape_code#Colors
const AnsiColor('0') - red → const AnsiColor
-
this class abstracts how ansi colors are defined
if you want to know more about ansi colors: https://en.wikipedia.org/wiki/ANSI_escape_code#Colors
const AnsiColor('1') - green → const AnsiColor
-
this class abstracts how ansi colors are defined
if you want to know more about ansi colors: https://en.wikipedia.org/wiki/ANSI_escape_code#Colors
const AnsiColor('2') - yellow → const AnsiColor
-
this class abstracts how ansi colors are defined
if you want to know more about ansi colors: https://en.wikipedia.org/wiki/ANSI_escape_code#Colors
const AnsiColor('3') - blue → const AnsiColor
-
this class abstracts how ansi colors are defined
if you want to know more about ansi colors: https://en.wikipedia.org/wiki/ANSI_escape_code#Colors
const AnsiColor('4') - magenta → const AnsiColor
-
this class abstracts how ansi colors are defined
if you want to know more about ansi colors: https://en.wikipedia.org/wiki/ANSI_escape_code#Colors
const AnsiColor('5') - cyan → const AnsiColor
-
this class abstracts how ansi colors are defined
if you want to know more about ansi colors: https://en.wikipedia.org/wiki/ANSI_escape_code#Colors
const AnsiColor('6') - white → const AnsiColor
-
this class abstracts how ansi colors are defined
if you want to know more about ansi colors: https://en.wikipedia.org/wiki/ANSI_escape_code#Colors
const AnsiColor('7') - defaultColor → const AnsiColor
-
this class abstracts how ansi colors are defined
if you want to know more about ansi colors: https://en.wikipedia.org/wiki/ANSI_escape_code#Colors
const AnsiColor('9')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
the value of the color in ansi escape
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromRgp(
{int red = 0, int green = 0, int blue = 0}) → IAnsiColor - creates a SGR parameter that is using 24bit format for colors